# weighbridge-simulator

A command line tool continuously send data to a serial port to simulate
weighbridge communicating.

## License

Copyright (C) 2024 Garrett HE <garrett.he@outlook.com>

The GNU General Public License (GPL) version 3, see [COPYING](./COPYING).
